@@ -10,7 +10,7 @@ module ActionCable
     MAJOR = 6
     MINOR = 1
     TINY  = 7
-    PRE   = nil
+    PRE   = "10"
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
