@@ -118,4 +118,55 @@ class ParametersMutatorsTest < ActiveSupport::TestCase
   test "transform_values! retains unpermitted status" do
     assert_not_predicate @params.transform_values! { |v| v }, :permitted?
   end
+
+  test "deep_transform_keys! retains permitted status" do
+    @params.permit!
+    assert_predicate @params.deep_transform_keys! { |k| k }, :permitted?
+  end
+
+  test "deep_transform_keys! retains unpermitted status" do
+    assert_not_predicate @params.deep_transform_keys! { |k| k }, :permitted?
+  end
+
+  test "compact retains permitted status" do
+    @params.permit!
+    assert_predicate @params.compact, :permitted?
+  end
+
+  test "compact retains unpermitted status" do
+    assert_not_predicate @params.compact, :permitted?
+  end
+
+  test "compact! returns nil when no values are nil" do
+    assert_nil @params.compact!
+  end
+
+  test "compact! retains permitted status" do
+    @params[:person] = nil
+    @params.permit!
+    assert_predicate @params.compact!, :permitted?
+  end
+
+  test "compact! retains unpermitted status" do
+    @params[:person] = nil
+    assert_not_predicate @params.compact!, :permitted?
+  end
+
+  test "compact_blank retains permitted status" do
+    @params.permit!
+    assert_predicate @params.compact_blank, :permitted?
+  end
+
+  test "compact_blank retains unpermitted status" do
+    assert_not_predicate @params.compact_blank, :permitted?
+  end
+
+  test "compact_blank! retains permitted status" do
+    @params.permit!
+    assert_predicate @params.compact_blank!, :permitted?
+  end
+
+  test "compact_blank! retains unpermitted status" do
+    assert_not_predicate @params.compact_blank!, :permitted?
+  end
 end
