@@ -17,6 +17,12 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
     end
   end
 
+  class SimpleController < ActionController::Base
+    def hello
+      self.response_body = "hello"
+    end
+  end
+
   class Boomer
     attr_accessor :closed
 
@@ -67,7 +73,8 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
       when "/pass"
         [404, { "X-Cascade" => "pass" }, self]
       when "/not_found"
-        raise AbstractController::ActionNotFound
+        controller = SimpleController.new
+        raise AbstractController::ActionNotFound.new(nil, controller, :not_found)
       when "/runtime_error"
         raise RuntimeError
       when "/method_not_allowed"
@@ -81,7 +88,7 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
       when "/unprocessable_entity"
         raise ActionController::InvalidAuthenticityToken
       when "/invalid_mimetype"
-        raise Mime::Type::InvalidMimeType
+        raise ActionDispatch::Http::MimeNegotiation::InvalidType
       when "/not_found_original_exception"
         begin
           raise AbstractController::ActionNotFound.new
@@ -101,7 +108,7 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
       when "/missing_keys"
         raise ActionController::UrlGenerationError, "No route matches"
       when "/parameter_missing"
-        raise ActionController::ParameterMissing, :missing_param_key
+        raise ActionController::ParameterMissing.new(:missing_param_key, %w(valid_param_key))
       when "/original_syntax_error"
         eval "broke_syntax =" # `eval` need for raise native SyntaxError at runtime
       when "/syntax_error_into_view"
@@ -137,6 +144,7 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
   DevelopmentApp = ActionDispatch::DebugExceptions.new(Boomer.new(true), RoutesApp)
   InterceptedApp = ActionDispatch::DebugExceptions.new(Boomer.new(true), RoutesApp, :default, [Interceptor])
   BadInterceptedApp = ActionDispatch::DebugExceptions.new(Boomer.new(true), RoutesApp, :default, [BadInterceptor])
+  ApiApp = ActionDispatch::DebugExceptions.new(Boomer.new(true), RoutesApp, :api)
 
   test "skip diagnosis if not showing detailed exceptions" do
     @app = ProductionApp
@@ -191,31 +199,38 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
 
     get "/", headers: { "action_dispatch.show_exceptions" => true }
     assert_response 500
+    assert_match(/<body>/, body)
     assert_match(/puke/, body)
 
     get "/not_found", headers: { "action_dispatch.show_exceptions" => true }
     assert_response 404
+    assert_match(/<body>/, body)
     assert_match(/#{AbstractController::ActionNotFound.name}/, body)
 
     get "/method_not_allowed", headers: { "action_dispatch.show_exceptions" => true }
     assert_response 405
+    assert_match(/<body>/, body)
     assert_match(/ActionController::MethodNotAllowed/, body)
 
     get "/unknown_http_method", headers: { "action_dispatch.show_exceptions" => true }
     assert_response 405
+    assert_match(/<body>/, body)
     assert_match(/ActionController::UnknownHttpMethod/, body)
 
     get "/bad_request", headers: { "action_dispatch.show_exceptions" => true }
     assert_response 400
+    assert_match(/<body>/, body)
     assert_match(/ActionController::BadRequest/, body)
 
     get "/parameter_missing", headers: { "action_dispatch.show_exceptions" => true }
     assert_response 400
+    assert_match(/<body>/, body)
     assert_match(/ActionController::ParameterMissing/, body)
 
     get "/invalid_mimetype", headers: { "Accept" => "text/html,*", "action_dispatch.show_exceptions" => true }
     assert_response 406
-    assert_match(/Mime::Type::InvalidMimeType/, body)
+    assert_match(/<body>/, body)
+    assert_match(/ActionDispatch::Http::MimeNegotiation::InvalidType/, body)
   end
 
   test "rescue with text error for xhr request" do
@@ -269,7 +284,7 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
   end
 
   test "rescue with JSON error for JSON API request" do
-    @app = ActionDispatch::DebugExceptions.new(Boomer.new(true), RoutesApp, :api)
+    @app = ApiApp
 
     get "/", headers: { "action_dispatch.show_exceptions" => true }, as: :json
     assert_response 500
@@ -307,10 +322,32 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
     assert_no_match(/<body>/, body)
     assert_equal "application/json", response.media_type
     assert_match(/ActionController::ParameterMissing/, body)
+
+    get "/invalid_mimetype", headers: { "Accept" => "text/html,*", "action_dispatch.show_exceptions" => true }, as: :json
+    assert_response 406
+    assert_no_match(/<body>/, body)
+    assert_equal "application/json", response.media_type
+    assert_match(/ActionDispatch::Http::MimeNegotiation::InvalidType/, body)
+  end
+
+  if defined?(DidYouMean) && DidYouMean.respond_to?(:correct_error)
+    test "rescue with suggestions" do
+      @app = DevelopmentApp
+
+      get "/not_found", headers: { "action_dispatch.show_exceptions" => true }
+      assert_response 404
+      assert_select("b", /Did you mean\?/)
+      assert_select("li", "hello")
+
+      get "/parameter_missing", headers: { "action_dispatch.show_exceptions" => true }
+      assert_response 400
+      assert_select("b", /Did you mean\?/)
+      assert_select("li", "valid_param_key")
+    end
   end
 
   test "rescue with HTML format for HTML API request" do
-    @app = ActionDispatch::DebugExceptions.new(Boomer.new(true), RoutesApp, :api)
+    @app = ApiApp
 
     get "/index.html", headers: { "action_dispatch.show_exceptions" => true }
     assert_response 500
@@ -321,7 +358,7 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
   end
 
   test "rescue with XML format for XML API requests" do
-    @app = ActionDispatch::DebugExceptions.new(Boomer.new(true), RoutesApp, :api)
+    @app = ApiApp
 
     get "/index.xml", headers: { "action_dispatch.show_exceptions" => true }
     assert_response 500
@@ -335,7 +372,7 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
     ActionDispatch::IntegrationTest.register_encoder(:wibble,
       param_encoder: -> params { params })
 
-    @app = ActionDispatch::DebugExceptions.new(Boomer.new(true), RoutesApp, :api)
+    @app = ApiApp
 
     get "/index", headers: { "action_dispatch.show_exceptions" => true }, as: :wibble
     assert_response 500
@@ -484,6 +521,8 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
   end
 
   test "logs exception backtrace when all lines silenced" do
+    @app = DevelopmentApp
+
     output = StringIO.new
     backtrace_cleaner = ActiveSupport::BacktraceCleaner.new
     backtrace_cleaner.add_silencer { true }
@@ -496,6 +535,49 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
     assert_operator((output.rewind && output.read).lines.count, :>, 10)
   end
 
+  test "doesn't log the framework backtrace when error type is a routing error" do
+    @app = ProductionApp
+
+    output = StringIO.new
+    backtrace_cleaner = ActiveSupport::BacktraceCleaner.new
+    backtrace_cleaner.add_silencer { true }
+
+    env = { "action_dispatch.show_exceptions"   => true,
+            "action_dispatch.logger"            => Logger.new(output),
+            "action_dispatch.backtrace_cleaner" => backtrace_cleaner }
+
+    assert_raises ActionController::RoutingError do
+      get "/pass", headers: env
+    end
+
+    log = output.rewind && output.read
+
+    assert_includes log, "ActionController::RoutingError (No route matches [GET] \"/pass\")"
+    assert_equal 3, log.lines.count
+  end
+
+  test "doesn't log the framework backtrace when error type is a invalid mine type" do
+    @app = ProductionApp
+
+    output = StringIO.new
+    backtrace_cleaner = ActiveSupport::BacktraceCleaner.new
+    backtrace_cleaner.add_silencer { true }
+
+    env = { "Accept" => "text/html,*",
+            "action_dispatch.show_exceptions"   => true,
+            "action_dispatch.logger"            => Logger.new(output),
+            "action_dispatch.backtrace_cleaner" => backtrace_cleaner }
+
+    assert_raises ActionDispatch::Http::MimeNegotiation::InvalidType do
+      get "/invalid_mimetype", headers: env
+    end
+
+    log = output.rewind && output.read
+
+    assert_includes log, "ActionDispatch::Http::MimeNegotiation::InvalidType (ActionDispatch::Http::MimeNegotiation::InvalidType)"
+    assert_equal 3, log.lines.count
+  end
+
   test "display backtrace when error type is SyntaxError" do
     @app = DevelopmentApp
 
@@ -539,15 +621,17 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
     @app = DevelopmentApp
     Rails.stub :root, Pathname.new(".") do
       cleaner = ActiveSupport::BacktraceCleaner.new.tap do |bc|
-        bc.add_silencer { |line| line =~ /method_that_raises/ }
-        bc.add_silencer { |line| line !~ %r{test/dispatch/debug_exceptions_test.rb} }
+        bc.add_silencer { |line| line.match?(/method_that_raises/) }
+        bc.add_silencer { |line| !line.match?(%r{test/dispatch/debug_exceptions_test.rb}) }
       end
 
       get "/framework_raises", headers: { "action_dispatch.backtrace_cleaner" => cleaner }
 
       # Assert correct error
       assert_response 500
-      assert_select "h2", /error in framework/
+      assert_select "div.exception-message" do
+        assert_select "div", /error in framework/
+      end
 
       # assert source view line is the call to method_that_raises
       assert_select "div.source:not(.hidden)" do
@@ -555,7 +639,7 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
       end
 
       # assert first source view (hidden) that throws the error
-      assert_select "div.source:first" do
+      assert_select "div.source" do
         assert_select "pre .line.active", /raise StandardError\.new/
       end
 
@@ -591,14 +675,16 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
     @app = DevelopmentApp
     Rails.stub :root, Pathname.new(".") do
       cleaner = ActiveSupport::BacktraceCleaner.new.tap do |bc|
-        bc.add_silencer { |line| line !~ %r{test/dispatch/debug_exceptions_test.rb} }
+        bc.add_silencer { |line| !line.match?(%r{test/dispatch/debug_exceptions_test.rb}) }
       end
 
       get "/nested_exceptions", headers: { "action_dispatch.backtrace_cleaner" => cleaner }
 
       # Assert correct error
       assert_response 500
-      assert_select "h2", /Third error/
+      assert_select "div.exception-message" do
+        assert_select "div", /Third error/
+      end
 
       # assert source view line shows the last error
       assert_select "div.source:not(.hidden)" do
@@ -626,7 +712,7 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
     @app = DevelopmentApp
     Rails.stub :root, Pathname.new(".") do
       cleaner = ActiveSupport::BacktraceCleaner.new.tap do |bc|
-        bc.add_silencer { |line| line !~ %r{test/dispatch/debug_exceptions_test.rb} }
+        bc.add_silencer { |line| !line.match?(%r{test/dispatch/debug_exceptions_test.rb}) }
       end
 
       get "/actionable_error", headers: { "action_dispatch.backtrace_cleaner" => cleaner }
@@ -667,7 +753,9 @@ class DebugExceptionsTest < ActionDispatch::IntegrationTest
     get "/nil_annoted_source_code_error", headers: { "action_dispatch.show_exceptions" => true, "action_dispatch.logger" => logger }
 
     assert_select "header h1", /DebugExceptionsTest::Boomer::NilAnnotedSourceCodeError/
-    assert_select "#container h2", /nil annoted_source_code/
+    assert_select "#container div.exception-message" do
+      assert_select "div", /nil annoted_source_code/
+    end
   end
 
   test "debug exceptions app shows diagnostics for template errors that contain UTF-8 characters" do
