@@ -14,8 +14,10 @@ module ActionText
   autoload :Attribute
   autoload :Content
   autoload :Fragment
+  autoload :FixtureSet
   autoload :HtmlConversion
   autoload :PlainTextConversion
+  autoload :Rendering
   autoload :Serialization
   autoload :TrixAttachment
 
