@@ -32,7 +32,7 @@ class ActionText::FormHelperTest < ActionView::TestCase
 
     assert_dom_equal \
       '<form action="/messages" accept-charset="UTF-8" data-remote="true" method="post">' \
-        '<input type="hidden" name="message[content]" id="message_content_trix_input_message" />' \
+        '<input type="hidden" name="message[content]" id="message_content_trix_input_message" autocomplete="off" />' \
         '<trix-editor id="message_content" input="message_content_trix_input_message" class="trix-content" data-direct-upload-url="http://test.host/rails/active_storage/direct_uploads" data-blob-url-template="http://test.host/rails/active_storage/blobs/redirect/:signed_id/:filename">' \
         "</trix-editor>" \
       "</form>",
@@ -46,7 +46,7 @@ class ActionText::FormHelperTest < ActionView::TestCase
 
     assert_dom_equal \
       '<form action="/messages" accept-charset="UTF-8" data-remote="true" method="post">' \
-        '<input type="hidden" name="message[content]" id="message_content_trix_input_message" />' \
+        '<input type="hidden" name="message[content]" id="message_content_trix_input_message" autocomplete="off" />' \
         '<trix-editor id="message_content" input="message_content_trix_input_message" class="custom-class" data-direct-upload-url="http://test.host/rails/active_storage/direct_uploads" data-blob-url-template="http://test.host/rails/active_storage/blobs/redirect/:signed_id/:filename">' \
         "</trix-editor>" \
       "</form>",
@@ -60,7 +60,7 @@ class ActionText::FormHelperTest < ActionView::TestCase
 
     assert_dom_equal \
       '<form action="/messages" accept-charset="UTF-8" data-remote="true" method="post">' \
-        '<input type="hidden" name="message[not_an_attribute]" id="message_not_an_attribute_trix_input_message" />' \
+        '<input type="hidden" name="message[not_an_attribute]" id="message_not_an_attribute_trix_input_message" autocomplete="off" />' \
         '<trix-editor id="message_not_an_attribute" input="message_not_an_attribute_trix_input_message" class="trix-content" data-direct-upload-url="http://test.host/rails/active_storage/direct_uploads" data-blob-url-template="http://test.host/rails/active_storage/blobs/redirect/:signed_id/:filename">' \
         "</trix-editor>" \
       "</form>",
@@ -74,7 +74,7 @@ class ActionText::FormHelperTest < ActionView::TestCase
 
     assert_dom_equal \
       '<form action="/messages" accept-charset="UTF-8" data-remote="true" method="post">' \
-        '<input type="hidden" name="message[content]" id="trix_input_1" />' \
+        '<input type="hidden" name="message[content]" id="trix_input_1" autocomplete="off" />' \
         '<trix-editor id="message_content" input="trix_input_1" class="trix-content" data-direct-upload-url="http://test.host/rails/active_storage/direct_uploads" data-blob-url-template="http://test.host/rails/active_storage/blobs/redirect/:signed_id/:filename">' \
         "</trix-editor>" \
       "</form>",
@@ -88,7 +88,7 @@ class ActionText::FormHelperTest < ActionView::TestCase
 
     assert_dom_equal \
       '<form action="/messages" accept-charset="UTF-8" data-remote="true" method="post">' \
-        '<input type="hidden" name="message[content]" id="message_content_trix_input_message" />' \
+        '<input type="hidden" name="message[content]" id="message_content_trix_input_message" autocomplete="off" />' \
         '<trix-editor placeholder="Content" id="message_content" input="message_content_trix_input_message" class="trix-content" data-direct-upload-url="http://test.host/rails/active_storage/direct_uploads" data-blob-url-template="http://test.host/rails/active_storage/blobs/redirect/:signed_id/:filename">' \
         "</trix-editor>" \
       "</form>",
@@ -104,7 +104,7 @@ class ActionText::FormHelperTest < ActionView::TestCase
 
     assert_dom_equal \
       '<form action="/messages" accept-charset="UTF-8" data-remote="true" method="post">' \
-        '<input type="hidden" name="message[title]" id="message_title_trix_input_message" />' \
+        '<input type="hidden" name="message[title]" id="message_title_trix_input_message" autocomplete="off" />' \
         '<trix-editor placeholder="Story title" id="message_title" input="message_title_trix_input_message" class="trix-content" data-direct-upload-url="http://test.host/rails/active_storage/direct_uploads" data-blob-url-template="http://test.host/rails/active_storage/blobs/redirect/:signed_id/:filename">' \
         "</trix-editor>" \
       "</form>",
@@ -118,7 +118,7 @@ class ActionText::FormHelperTest < ActionView::TestCase
 
     assert_dom_equal \
       '<form action="/messages" accept-charset="UTF-8" data-remote="true" method="post">' \
-        '<input type="hidden" name="message[title]" id="message_title_trix_input_message" value="&lt;h1&gt;hello world&lt;/h1&gt;" />' \
+        '<input type="hidden" name="message[title]" id="message_title_trix_input_message" value="&lt;h1&gt;hello world&lt;/h1&gt;" autocomplete="off" />' \
         '<trix-editor id="message_title" input="message_title_trix_input_message" class="trix-content" data-direct-upload-url="http://test.host/rails/active_storage/direct_uploads" data-blob-url-template="http://test.host/rails/active_storage/blobs/redirect/:signed_id/:filename">' \
         "</trix-editor>" \
       "</form>",
