@@ -17,16 +17,6 @@ class LookupContextTest < ActiveSupport::TestCase
     I18n.locale = :en
   end
 
-  test "rendered_format is deprecated" do
-    assert_deprecated do
-      @lookup_context.rendered_format = "foo"
-    end
-
-    assert_deprecated do
-      assert_equal "foo", @lookup_context.rendered_format
-    end
-  end
-
   test "allows to override default_formats with ActionView::Base.default_formats" do
     formats = ActionView::Base.default_formats
     ActionView::Base.default_formats = [:foo, :bar]
@@ -140,14 +130,6 @@ class LookupContextTest < ActiveSupport::TestCase
   test "adds fallbacks to view paths when required" do
     assert_equal 1, @lookup_context.view_paths.size
 
-    assert_deprecated do
-      @lookup_context.with_fallbacks do
-        assert_equal 3, @lookup_context.view_paths.size
-        assert_includes @lookup_context.view_paths, ActionView::FallbackFileSystemResolver.instances[0]
-        assert_includes @lookup_context.view_paths, ActionView::FallbackFileSystemResolver.instances[1]
-      end
-    end
-
     @lookup_context = @lookup_context.with_fallbacks
 
     assert_equal 3, @lookup_context.view_paths.size
@@ -155,17 +137,10 @@ class LookupContextTest < ActiveSupport::TestCase
     assert_includes @lookup_context.view_paths, ActionView::FallbackFileSystemResolver.instances[1]
   end
 
-  test "add fallbacks just once in nested fallbacks calls" do
-    assert_deprecated do
-      @lookup_context.with_fallbacks do
-        @lookup_context.with_fallbacks do
-          assert_equal 3, @lookup_context.view_paths.size
-        end
-      end
+  test "with_fallbacks with block raises an ArgumentError" do
+    assert_raises(ArgumentError) do
+      @lookup_context.with_fallbacks { }
     end
-
-    @lookup_context = @lookup_context.with_fallbacks.with_fallbacks
-    assert_equal 3, @lookup_context.view_paths.size
   end
 
   test "generates a new details key for each details hash" do
@@ -190,33 +165,30 @@ class LookupContextTest < ActiveSupport::TestCase
     assert_equal 3, keys.uniq.size
   end
 
-  test "gives the key forward to the resolver, so it can be used as cache key" do
-    @lookup_context = build_lookup_context(ActionView::FixtureResolver.new("test/_foo.erb" => "Foo"), {})
+  test "uses details as part of cache key" do
+    fixtures = {
+      "test/_foo.erb" => "Foo",
+      "test/_foo.da.erb" => "Bar",
+    }
+    @lookup_context = build_lookup_context(ActionView::FixtureResolver.new(fixtures), {})
+
     template = @lookup_context.find("foo", %w(test), true)
+    original_template = template
     assert_equal "Foo", template.source
 
-    # Now we are going to change the template, but it won't change the returned template
-    # since we will hit the cache.
-    @lookup_context.view_paths.first.data["test/_foo.erb"] = "Bar"
+    # We should get the same template
     template = @lookup_context.find("foo", %w(test), true)
-    assert_equal "Foo", template.source
+    assert_same original_template, template
 
-    # This time we will change the locale. The updated template should be picked since
-    # lookup_context generated a new key after we changed the locale.
+    # Using a different locale we get a different view
     @lookup_context.locale = :da
     template = @lookup_context.find("foo", %w(test), true)
     assert_equal "Bar", template.source
 
-    # Now we will change back the locale and it will still pick the old template.
-    # This is expected because lookup_context will reuse the previous key for :en locale.
+    # Using en we get the original view
     @lookup_context.locale = :en
     template = @lookup_context.find("foo", %w(test), true)
-    assert_equal "Foo", template.source
-
-    # Finally, we can expire the cache. And the expected template will be used.
-    @lookup_context.view_paths.first.clear_cache
-    template = @lookup_context.find("foo", %w(test), true)
-    assert_equal "Bar", template.source
+    assert_same original_template, template
   end
 
   test "can disable the cache on demand" do
