@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 require "abstract_unit"
-require "action_view/renderer/partial_renderer"
+require "action_view/renderer/collection_renderer"
 
 class PartialIterationTest < ActiveSupport::TestCase
   def test_has_size_and_index
