@@ -37,17 +37,20 @@ module('data-remote', {
         href: '/echo',
         'data-remote': 'true',
         disabled: 'disabled',
-        text: 'Disabed link'
+        text: 'Disabled link'
       }))
       .find('form').append($('<input type="text" name="user_name" value="john">'))
 
+    $('#qunit-fixture').append($('<div />', {
+      id: 'edit-div', 'contenteditable': 'true'
+    }))
   }
 })
 
 asyncTest('ctrl-clicking on a link does not fire ajaxyness', 0, function() {
   var link = $('a[data-remote]')
 
-  // Ideally, we'd setup an iframe to intercept normal link clicks
+  // Ideally, we'd set up an iframe to intercept normal link clicks
   // and add a test to make sure the iframe:loaded event is triggered.
   // However, jquery doesn't actually cause a native `click` event and
   // follow links using `trigger('click')`, it only fires bindings.
@@ -66,7 +69,7 @@ asyncTest('ctrl-clicking on a link does not fire ajaxyness', 0, function() {
 asyncTest('right/mouse-wheel-clicking on a link does not fire ajaxyness', 0, function() {
   var link = $('a[data-remote]')
 
-  // Ideally, we'd setup an iframe to intercept normal link clicks
+  // Ideally, we'd set up an iframe to intercept normal link clicks
   // and add a test to make sure the iframe:loaded event is triggered.
   // However, jquery doesn't actually cause a native `click` event and
   // follow links using `trigger('click')`, it only fires bindings.
@@ -184,7 +187,7 @@ asyncTest('clicking on a button with data-remote attribute', 5, function() {
 asyncTest('right/mouse-wheel-clicking on a button with data-remote attribute does not fire ajaxyness', 0, function() {
   var button = $('button[data-remote]')
 
-  // Ideally, we'd setup an iframe to intercept normal link clicks
+  // Ideally, we'd set up an iframe to intercept normal link clicks
   // and add a test to make sure the iframe:loaded event is triggered.
   // However, jquery doesn't actually cause a native `click` event and
   // follow links using `trigger('click')`, it only fires bindings.
@@ -490,7 +493,7 @@ asyncTest('changing a select option without "data-url" attribute still fires aja
   setTimeout(function() { start() }, 20)
 })
 
-asyncTest('inputs inside disabled fieldset are not submited on remote forms', 3, function() {
+asyncTest('inputs inside disabled fieldset are not submitted on remote forms', 3, function() {
   $('form')
     .append('<fieldset>\
       <input name="description" value="A wise man" />\
@@ -508,4 +511,21 @@ asyncTest('inputs inside disabled fieldset are not submited on remote forms', 3,
     .triggerNative('submit')
 })
 
+asyncTest('clicking on a link with contenteditable attribute does not fire ajaxyness', 0, function() {
+  var contenteditable_div = $('#qunit-fixture').find('div')
+  var link = $('a[data-remote]')
+  contenteditable_div.append(link)
+
+  link
+    .bindNative('ajax:beforeSend', function() {
+      ok(false, 'ajax should not be triggered')
+    })
+    .bindNative('click', function(e) {
+      e.preventDefault()
+    })
+    .triggerNative('click')
+
+  setTimeout(function() { start() }, 20)
+})
+
 })()
