@@ -3,4 +3,4 @@
 require "support/que/inline"
 
 ActiveJob::Base.queue_adapter = :que
-Que.mode = :sync
+Que.run_synchronously = true
