@@ -534,7 +534,7 @@ class EnqueuedJobsTest < ActiveJob::TestCase
       end
     end
 
-    assert_equal 'No enqueued job found with {:job=>NestedJob, :queue=>"low"}', error.message
+    assert_match(/No enqueued job found with {:job=>NestedJob, :queue=>"low"}/, error.message)
   end
 
   def test_assert_enqueued_with_with_no_block_failure
@@ -548,7 +548,7 @@ class EnqueuedJobsTest < ActiveJob::TestCase
       assert_enqueued_with(job: NestedJob, queue: "low")
     end
 
-    assert_equal 'No enqueued job found with {:job=>NestedJob, :queue=>"low"}', error.message
+    assert_match(/No enqueued job found with {:job=>NestedJob, :queue=>"low"}/, error.message)
   end
 
   def test_assert_enqueued_with_args
@@ -559,25 +559,24 @@ class EnqueuedJobsTest < ActiveJob::TestCase
     end
   end
 
-  def test_assert_enqueued_with_selective_args
-    args = ->(job_args) do
-      assert_equal 1, job_args.first[:argument1]
-      assert job_args.first[:argument2].key?(:b)
-    end
+  def test_assert_enqueued_with_supports_matcher_procs
+    facets = {
+      job: HelloJob,
+      args: ["Rails"],
+      at: Date.tomorrow.noon,
+      queue: "important",
+    }
 
-    assert_enqueued_with(job: MultipleKwargsJob, args: args) do
-      MultipleKwargsJob.perform_later(argument2: { b: 2, a: 1 }, argument1: 1)
-    end
-  end
+    facets[:job].set(queue: facets[:queue], wait_until: facets[:at]).perform_later(*facets[:args])
 
-  def test_assert_enqueued_with_selective_args_fails
-    args = ->(job_args) do
-      false
-    end
+    facets.each do |facet, value|
+      matcher = ->(job_value) { job_value == value }
+      refuser = ->(job_value) { false }
 
-    assert_raise ActiveSupport::TestCase::Assertion do
-      assert_enqueued_with(job: MultipleKwargsJob, args: args) do
-        MultipleKwargsJob.perform_later(argument2: { b: 2, a: 1 }, argument1: 1)
+      assert_enqueued_with(**{ facet => matcher })
+
+      assert_raises ActiveSupport::TestCase::Assertion do
+        assert_enqueued_with(**{ facet => refuser })
       end
     end
   end
@@ -609,6 +608,21 @@ class EnqueuedJobsTest < ActiveJob::TestCase
     end
   end
 
+  def test_assert_enqueued_with_time_and_time_precision
+    time_with_zone = ActiveSupport::TimeWithZone.new(
+      Time.utc(1999, 12, 31, 23, 59, "59.123456789".to_r),
+      ActiveSupport::TimeZone["Tokyo"]
+    )
+
+    time = Time.at(946702800, 1234567, :nanosecond)
+    date_time = DateTime.new(2001, 2, 3, 4, 5, 6.123456, "+03:00")
+    args = [{ argument1: [time_with_zone, time, date_time] }]
+
+    assert_enqueued_with(job: MultipleKwargsJob, args: args) do
+      MultipleKwargsJob.perform_later(argument1: [time_with_zone, time, date_time])
+    end
+  end
+
   def test_assert_enqueued_with_with_no_block_args
     assert_raise ArgumentError do
       NestedJob.set(wait_until: Date.tomorrow.noon).perform_later
@@ -671,8 +685,8 @@ class EnqueuedJobsTest < ActiveJob::TestCase
         HelloJob.perform_later(ricardo)
       end
     end
-
-    assert_equal "No enqueued job found with {:job=>HelloJob, :args=>[#{wilma.inspect}]}", error.message
+    assert_match(/No enqueued job found with {:job=>HelloJob, :args=>\[#{wilma.inspect}\]}/, error.message)
+    assert_match(/Potential matches: {.*?:job=>HelloJob, :args=>\[#<Person.* @id=\"9\"\>\], :queue=>\"default\"}/, error.message)
   end
 
   def test_assert_enqueued_with_failure_with_no_block_with_global_id_args
@@ -683,7 +697,8 @@ class EnqueuedJobsTest < ActiveJob::TestCase
       assert_enqueued_with(job: HelloJob, args: [wilma])
     end
 
-    assert_equal "No enqueued job found with {:job=>HelloJob, :args=>[#{wilma.inspect}]}", error.message
+    assert_match(/No enqueued job found with {:job=>HelloJob, :args=>\[#{wilma.inspect}\]}/, error.message)
+    assert_match(/Potential matches: {.*?:job=>HelloJob, :args=>\[#<Person.* @id=\"9\"\>\], :queue=>\"default\"}/, error.message)
   end
 
   def test_assert_enqueued_with_does_not_change_jobs_count
@@ -882,6 +897,105 @@ class PerformedJobsTest < ActiveJob::TestCase
     assert_performed_jobs 1, only: LoggingJob, queue: :other_queue
   end
 
+  def test_perform_enqueued_jobs_with_at_with_job_performed_now
+    HelloJob.perform_later("kevin")
+
+    perform_enqueued_jobs(at: Time.now)
+
+    assert_performed_jobs 1
+  end
+
+  def test_perform_enqueued_jobs_with_at_with_job_wait_in_past
+    HelloJob.set(wait_until: Time.now - 100).perform_later("kevin")
+
+    perform_enqueued_jobs(at: Time.now)
+
+    assert_performed_jobs 1
+  end
+
+  def test_perform_enqueued_jobs_with_at_with_job_wait_in_future
+    HelloJob.set(wait_until: Time.now + 100).perform_later("kevin")
+
+    perform_enqueued_jobs(at: Time.now)
+
+    assert_performed_jobs 0
+  end
+
+  def test_perform_enqueued_jobs_block_with_at_with_job_performed_now
+    perform_enqueued_jobs(at: Time.now) do
+      HelloJob.perform_later("kevin")
+    end
+
+    assert_performed_jobs 1
+  end
+
+  def test_perform_enqueued_jobs_block_with_at_with_job_wait_in_past
+    perform_enqueued_jobs(at: Time.now) do
+      HelloJob.set(wait_until: Time.now - 100).perform_later("kevin")
+    end
+
+    assert_performed_jobs 1
+  end
+
+  def test_perform_enqueued_jobs_block_with_at_with_job_wait_in_future
+    perform_enqueued_jobs(at: Time.now) do
+      HelloJob.set(wait_until: Time.now + 100).perform_later("kevin")
+    end
+
+    assert_performed_jobs 0
+  end
+
+  def test_perform_enqueued_jobs_properly_count_job_that_raises
+    RaisingJob.perform_later("NotImplementedError")
+
+    assert_raises(NotImplementedError) do
+      perform_enqueued_jobs(only: RaisingJob)
+    end
+
+    assert_equal(1, performed_jobs.size)
+  end
+
+  def test_perform_enqueued_jobs_dont_perform_retries
+    RaisingJob.perform_later
+
+    assert_nothing_raised do
+      perform_enqueued_jobs(only: RaisingJob)
+    end
+
+    assert_equal(1, performed_jobs.size)
+    assert_equal(1, enqueued_jobs.size)
+  end
+
+  def test_perform_enqueued_jobs_without_block_removes_from_enqueued_jobs
+    HelloJob.perform_later("rafael")
+    assert_equal(0, performed_jobs.size)
+    assert_equal(1, enqueued_jobs.size)
+    perform_enqueued_jobs
+    assert_equal(1, performed_jobs.size)
+    assert_equal(0, enqueued_jobs.size)
+  end
+
+  def test_perform_enqueued_jobs_without_block_works_with_other_helpers
+    NestedJob.perform_later
+    assert_equal(0, performed_jobs.size)
+    assert_equal(1, enqueued_jobs.size)
+    assert_enqueued_jobs(1) do
+      assert_enqueued_with(job: LoggingJob) do
+        perform_enqueued_jobs
+      end
+    end
+    assert_equal(1, performed_jobs.size)
+    assert_equal(1, enqueued_jobs.size)
+  end
+
+  def test_perform_enqueued_jobs_without_block_only_performs_once
+    JobBuffer.clear
+    RescueJob.perform_later("no exception")
+    perform_enqueued_jobs
+    perform_enqueued_jobs
+    assert_equal(1, JobBuffer.values.size)
+  end
+
   def test_assert_performed_jobs
     assert_nothing_raised do
       assert_performed_jobs 1 do
@@ -1704,18 +1818,6 @@ class PerformedJobsTest < ActiveJob::TestCase
     end
   end
 
-  def test_assert_performed_with_with_at_option_as_a_proc
-    assert_performed_with(job: HelloJob, at: ->(at) { (4.minutes.from_now..6.minutes.from_now).cover?(at) }) do
-      HelloJob.set(wait: 5.minutes).perform_later
-    end
-
-    assert_raise ActiveSupport::TestCase::Assertion do
-      assert_performed_with(job: HelloJob, at: ->(at) { (1.minute.from_now..3.minutes.from_now).cover?(at) }) do
-        HelloJob.set(wait: 1.minute).perform_later
-      end
-    end
-  end
-
   def test_assert_performed_with_without_block_with_at_option
     HelloJob.set(wait_until: Date.tomorrow.noon).perform_later
 
@@ -1738,25 +1840,25 @@ class PerformedJobsTest < ActiveJob::TestCase
     end
   end
 
-  def test_assert_performed_with_selective_args
-    args = ->(job_args) do
-      assert_equal 1, job_args.first[:argument1]
-      assert job_args.first[:argument2].key?(:b)
-    end
+  def test_assert_performed_with_supports_matcher_procs
+    facets = {
+      job: HelloJob,
+      args: ["Rails"],
+      at: Date.tomorrow.noon,
+      queue: "important",
+    }
 
-    assert_performed_with(job: MultipleKwargsJob, args: args) do
-      MultipleKwargsJob.perform_later(argument2: { b: 2, a: 1 }, argument1: 1)
-    end
-  end
+    facets[:job].set(queue: facets[:queue], wait_until: facets[:at]).perform_later(*facets[:args])
+    perform_enqueued_jobs
 
-  def test_assert_performed_with_selective_args_fails
-    args = ->(job_args) do
-      false
-    end
+    facets.each do |facet, value|
+      matcher = ->(job_value) { job_value == value }
+      refuser = ->(job_value) { false }
 
-    assert_raise ActiveSupport::TestCase::Assertion do
-      assert_performed_with(job: MultipleKwargsJob, args: args) do
-        MultipleKwargsJob.perform_later(argument2: { b: 2, a: 1 }, argument1: 1)
+      assert_performed_with(**{ facet => matcher })
+
+      assert_raises ActiveSupport::TestCase::Assertion do
+        assert_performed_with(**{ facet => refuser })
       end
     end
   end
@@ -1810,8 +1912,8 @@ class PerformedJobsTest < ActiveJob::TestCase
         HelloJob.perform_later(ricardo)
       end
     end
-
-    assert_equal "No performed job found with {:job=>HelloJob, :args=>[#{wilma.inspect}]}", error.message
+    assert_match(/No performed job found with {:job=>HelloJob, :args=>\[#{wilma.inspect}\]}/, error.message)
+    assert_match(/Potential matches: {.*?:job=>HelloJob, :args=>\[#<Person.* @id=\"9\"\>\], :queue=>\"default\"}/, error.message)
   end
 
   def test_assert_performed_with_without_block_failure_with_global_id_args
@@ -1823,7 +1925,8 @@ class PerformedJobsTest < ActiveJob::TestCase
       assert_performed_with(job: HelloJob, args: [wilma])
     end
 
-    assert_equal "No performed job found with {:job=>HelloJob, :args=>[#{wilma.inspect}]}", error.message
+    assert_match(/No performed job found with {:job=>HelloJob, :args=>\[#{wilma.inspect}\]}/, error.message)
+    assert_match(/Potential matches: {.*?:job=>HelloJob, :args=>\[#<Person.* @id=\"9\"\>\], :queue=>\"default\"}/, error.message)
   end
 
   def test_assert_performed_with_does_not_change_jobs_count
@@ -1835,6 +1938,7 @@ class PerformedJobsTest < ActiveJob::TestCase
       HelloJob.perform_later
     end
 
+    assert_equal 0, queue_adapter.enqueued_jobs.count
     assert_equal 2, queue_adapter.performed_jobs.count
   end
 
@@ -1843,21 +1947,22 @@ class PerformedJobsTest < ActiveJob::TestCase
     perform_enqueued_jobs
     assert_performed_with(job: HelloJob)
 
-    perform_enqueued_jobs
     HelloJob.perform_later
+    perform_enqueued_jobs
     assert_performed_with(job: HelloJob)
 
+    assert_equal 0, queue_adapter.enqueued_jobs.count
     assert_equal 2, queue_adapter.performed_jobs.count
   end
 
   test "TestAdapter respect max attempts" do
-    RaisingJob.perform_later
-
-    assert_raises(RaisingJob::MyError) do
-      perform_enqueued_jobs
+    perform_enqueued_jobs(only: RaisingJob) do
+      assert_raises(RaisingJob::MyError) do
+        RaisingJob.perform_later
+      end
     end
 
-    assert_equal 2, queue_adapter.enqueued_jobs.count
+    assert_equal 2, queue_adapter.performed_jobs.count
   end
 end
 
