@@ -19,7 +19,6 @@ module TestCaseHelpers
   end
 
   private
-
     def jobs_manager
       JobsManager.current_manager
     end
@@ -33,14 +32,12 @@ module TestCaseHelpers
     end
 
     def wait_for_jobs_to_finish_for(seconds = 60)
-      begin
-        Timeout.timeout(seconds) do
-          while !job_executed do
-            sleep 0.25
-          end
+      Timeout.timeout(seconds) do
+        while !job_executed do
+          sleep 0.25
         end
-      rescue Timeout::Error
       end
+    rescue Timeout::Error
     end
 
     def job_file(id)
@@ -62,4 +59,8 @@ module TestCaseHelpers
     def job_executed_in_locale(id = @id)
       job_data(id)["locale"]
     end
+
+    def job_executed_in_timezone(id = @id)
+      job_data(id)["timezone"]
+    end
 end
