@@ -6,8 +6,6 @@ require "models/person"
 module ActiveRecord
   module ConnectionAdapters
     class ConnectionHandlerTest < ActiveRecord::TestCase
-      self.use_transactional_tests = false
-
       fixtures :people
 
       def setup
@@ -45,7 +43,9 @@ module ActiveRecord
         @prev_configs, ActiveRecord::Base.configurations = ActiveRecord::Base.configurations, config
 
         @handler.establish_connection(:common)
-        @handler.establish_connection(:primary)
+        assert_deprecated do
+          @handler.establish_connection(:primary)
+        end
         @handler.establish_connection(:readonly)
 
         assert_not_nil pool = @handler.retrieve_connection_pool("readonly")
@@ -74,6 +74,23 @@ module ActiveRecord
           ActiveRecord::Base.establish_connection :arunit
         end
 
+        def test_fixtures_dont_raise_if_theres_no_writing_pool_config
+          connection_handler = ActiveRecord::Base.connection_handler
+          ActiveRecord::Base.connection_handler = ActiveRecord::ConnectionAdapters::ConnectionHandler.new
+
+          assert_nothing_raised do
+            ActiveRecord::Base.connects_to(database: { reading: :arunit, writing: :arunit })
+          end
+
+          rw_conn = ActiveRecord::Base.connection_handler.retrieve_connection("ActiveRecord::Base", role: :writing)
+          ro_conn = ActiveRecord::Base.connection_handler.retrieve_connection("ActiveRecord::Base", role: :reading)
+
+          assert_equal rw_conn, ro_conn
+        ensure
+          ActiveRecord::Base.connection_handler = connection_handler
+          ActiveRecord::Base.establish_connection :arunit
+        end
+
         def test_setting_writing_role_while_using_another_named_role_does_not_raise
           connection_handler = ActiveRecord::Base.connection_handler
           ActiveRecord::Base.connection_handler = ActiveRecord::ConnectionAdapters::ConnectionHandler.new
@@ -93,7 +110,9 @@ module ActiveRecord
           config = { "primary" => { "adapter" => "sqlite3", "database" => "test/db/primary.sqlite3" } }
           ActiveRecord::Base.configurations = config
 
-          @handler.establish_connection(:primary)
+          assert_deprecated do
+            @handler.establish_connection(:primary)
+          end
 
           assert_not_deprecated do
             @handler.retrieve_connection("primary")
