@@ -217,17 +217,22 @@ module ActiveRecord
         with_change_table do |t|
           if RUBY_VERSION < "2.7"
             @connection.expect :add_column, nil, [:delete_me, :bar, :integer, {}]
+            @connection.expect :add_index, nil, [:delete_me, :bar, {}]
           else
             @connection.expect :add_column, nil, [:delete_me, :bar, :integer]
+            @connection.expect :add_index, nil, [:delete_me, :bar]
           end
-          @connection.expect :add_index, nil, [:delete_me, :bar, {}]
           t.column :bar, :integer, index: true
         end
       end
 
       def test_index_creates_index
         with_change_table do |t|
-          @connection.expect :add_index, nil, [:delete_me, :bar, {}]
+          if RUBY_VERSION < "2.7"
+            @connection.expect :add_index, nil, [:delete_me, :bar, {}]
+          else
+            @connection.expect :add_index, nil, [:delete_me, :bar]
+          end
           t.index :bar
         end
       end
@@ -262,7 +267,11 @@ module ActiveRecord
 
       def test_change_changes_column
         with_change_table do |t|
-          @connection.expect :change_column, nil, [:delete_me, :bar, :string, {}]
+          if RUBY_VERSION < "2.7"
+            @connection.expect :change_column, nil, [:delete_me, :bar, :string, {}]
+          else
+            @connection.expect :change_column, nil, [:delete_me, :bar, :string]
+          end
           t.change :bar, :string
         end
       end
@@ -281,24 +290,46 @@ module ActiveRecord
         end
       end
 
+      def test_change_null_changes_column
+        with_change_table do |t|
+          @connection.expect :change_column_null, nil, [:delete_me, :bar, true, nil]
+          t.change_null :bar, true
+        end
+      end
+
       def test_remove_drops_single_column
         with_change_table do |t|
-          @connection.expect :remove_columns, nil, [:delete_me, :bar]
+          if RUBY_VERSION < "2.7"
+            @connection.expect :remove_columns, nil, [:delete_me, :bar, {}]
+          else
+            @connection.expect :remove_columns, nil, [:delete_me, :bar]
+          end
           t.remove :bar
         end
       end
 
       def test_remove_drops_multiple_columns
         with_change_table do |t|
-          @connection.expect :remove_columns, nil, [:delete_me, :bar, :baz]
+          if RUBY_VERSION < "2.7"
+            @connection.expect :remove_columns, nil, [:delete_me, :bar, :baz, {}]
+          else
+            @connection.expect :remove_columns, nil, [:delete_me, :bar, :baz]
+          end
           t.remove :bar, :baz
         end
       end
 
+      def test_remove_drops_multiple_columns_when_column_options_are_given
+        with_change_table do |t|
+          @connection.expect :remove_columns, nil, [:delete_me, :bar, :baz, type: :string, null: false]
+          t.remove :bar, :baz, type: :string, null: false
+        end
+      end
+
       def test_remove_index_removes_index_with_options
         with_change_table do |t|
-          @connection.expect :remove_index, nil, [:delete_me, { unique: true }]
-          t.remove_index unique: true
+          @connection.expect :remove_index, nil, [:delete_me, :bar, { unique: true }]
+          t.remove_index :bar, unique: true
         end
       end
 
@@ -314,6 +345,20 @@ module ActiveRecord
           assert_equal :delete_me, t.name
         end
       end
+
+      def test_check_constraint_creates_check_constraint
+        with_change_table do |t|
+          @connection.expect :add_check_constraint, nil, [:delete_me, "price > discounted_price", name: "price_check"]
+          t.check_constraint "price > discounted_price", name: "price_check"
+        end
+      end
+
+      def test_remove_check_constraint_removes_check_constraint
+        with_change_table do |t|
+          @connection.expect :remove_check_constraint, nil, [:delete_me, name: "price_check"]
+          t.remove_check_constraint name: "price_check"
+        end
+      end
     end
   end
 end
