@@ -269,70 +269,48 @@ module ActiveRecord
         end
       end
 
-      def test_create_table_with_polymorphic_reference_uses_all_column_names_in_index
-        migration = Class.new(ActiveRecord::Migration[6.0]) {
-          def migrate(x)
-            create_table :more_testings do |t|
-              t.references :widget, polymorphic: true, index: true
-              t.belongs_to :gizmo, polymorphic: true, index: true
+      if current_adapter?(:SQLite3Adapter)
+        def test_references_stays_as_integer_column_on_create_table_with_reference_6_0
+          migration = Class.new(ActiveRecord::Migration[6.0]) {
+            def migrate(x)
+              create_table :more_testings do |t|
+                t.references :testings
+              end
             end
-          end
-        }.new
+          }.new
 
-        ActiveRecord::Migrator.new(:up, [migration], @schema_migration).migrate
+          ActiveRecord::Migrator.new(:up, [migration], @schema_migration).migrate
 
-        assert connection.index_exists?(:more_testings, [:widget_type, :widget_id], name: :index_more_testings_on_widget_type_and_widget_id)
-        assert connection.index_exists?(:more_testings, [:gizmo_type, :gizmo_id], name: :index_more_testings_on_gizmo_type_and_gizmo_id)
-      ensure
-        connection.drop_table :more_testings rescue nil
-      end
+          testings_id_column = connection.columns(:more_testings).find { |el| el.name == "testings_id" }
+          assert_equal "integer", testings_id_column.sql_type
+        ensure
+          connection.drop_table :more_testings rescue nil
+        end
 
-      def test_change_table_with_polymorphic_reference_uses_all_column_names_in_index
-        migration = Class.new(ActiveRecord::Migration[6.0]) {
-          def migrate(x)
-            change_table :testings do |t|
-              t.references :widget, polymorphic: true, index: true
-              t.belongs_to :gizmo, polymorphic: true, index: true
+        def test_references_stays_as_integer_column_on_add_reference_6_0
+          create_migration = Class.new(ActiveRecord::Migration[6.0]) {
+            def version; 100 end
+            def migrate(x)
+              create_table :more_testings do |t|
+                t.string :test
+              end
             end
-          end
-        }.new
+          }.new
 
-        ActiveRecord::Migrator.new(:up, [migration], @schema_migration).migrate
-
-        assert connection.index_exists?(:testings, [:widget_type, :widget_id], name: :index_testings_on_widget_type_and_widget_id)
-        assert connection.index_exists?(:testings, [:gizmo_type, :gizmo_id], name: :index_testings_on_gizmo_type_and_gizmo_id)
-      end
-
-      def test_create_join_table_with_polymorphic_reference_uses_all_column_names_in_index
-        migration = Class.new(ActiveRecord::Migration[6.0]) {
-          def migrate(x)
-            create_join_table :more, :testings do |t|
-              t.references :widget, polymorphic: true, index: true
-              t.belongs_to :gizmo, polymorphic: true, index: true
+          migration = Class.new(ActiveRecord::Migration[6.0]) {
+            def version; 101 end
+            def migrate(x)
+              add_reference :more_testings, :testings
             end
-          end
-        }.new
+          }.new
 
-        ActiveRecord::Migrator.new(:up, [migration], @schema_migration).migrate
+          ActiveRecord::Migrator.new(:up, [create_migration, migration], @schema_migration).migrate
 
-        assert connection.index_exists?(:more_testings, [:widget_type, :widget_id], name: :index_more_testings_on_widget_type_and_widget_id)
-        assert connection.index_exists?(:more_testings, [:gizmo_type, :gizmo_id], name: :index_more_testings_on_gizmo_type_and_gizmo_id)
-      ensure
-        connection.drop_table :more_testings rescue nil
-      end
-
-      def test_polymorphic_add_reference_uses_all_column_names_in_index
-        migration = Class.new(ActiveRecord::Migration[6.0]) {
-          def migrate(x)
-            add_reference :testings, :widget, polymorphic: true, index: true
-            add_belongs_to :testings, :gizmo, polymorphic: true, index: true
-          end
-        }.new
-
-        ActiveRecord::Migrator.new(:up, [migration], @schema_migration).migrate
-
-        assert connection.index_exists?(:testings, [:widget_type, :widget_id], name: :index_testings_on_widget_type_and_widget_id)
-        assert connection.index_exists?(:testings, [:gizmo_type, :gizmo_id], name: :index_testings_on_gizmo_type_and_gizmo_id)
+          testings_id_column = connection.columns(:more_testings).find { |el| el.name == "testings_id" }
+          assert_equal "integer", testings_id_column.sql_type
+        ensure
+          connection.drop_table :more_testings rescue nil
+        end
       end
 
       private
@@ -347,6 +325,132 @@ module ActiveRecord
   end
 end
 
+module LegacyPolymorphicReferenceIndexTestCases
+  attr_reader :connection
+
+  def setup
+    @connection = ActiveRecord::Base.connection
+    @schema_migration = @connection.schema_migration
+    @verbose_was = ActiveRecord::Migration.verbose
+    ActiveRecord::Migration.verbose = false
+
+    connection.create_table :testings, if_not_exists: true
+  end
+
+  def teardown
+    ActiveRecord::Migration.verbose = @verbose_was
+    ActiveRecord::SchemaMigration.delete_all rescue nil
+    connection.drop_table :testings rescue nil
+  end
+
+  def test_create_table_with_polymorphic_reference_uses_all_column_names_in_index
+    migration = Class.new(migration_class) {
+      def migrate(x)
+        create_table :more_testings do |t|
+          t.references :widget, polymorphic: true, index: true
+          t.belongs_to :gizmo, polymorphic: true, index: true
+        end
+      end
+    }.new
+
+    ActiveRecord::Migrator.new(:up, [migration], @schema_migration).migrate
+
+    assert connection.index_exists?(:more_testings, [:widget_type, :widget_id], name: :index_more_testings_on_widget_type_and_widget_id)
+    assert connection.index_exists?(:more_testings, [:gizmo_type, :gizmo_id], name: :index_more_testings_on_gizmo_type_and_gizmo_id)
+  ensure
+    connection.drop_table :more_testings rescue nil
+  end
+
+  def test_change_table_with_polymorphic_reference_uses_all_column_names_in_index
+    migration = Class.new(migration_class) {
+      def migrate(x)
+        change_table :testings do |t|
+          t.references :widget, polymorphic: true, index: true
+          t.belongs_to :gizmo, polymorphic: true, index: true
+        end
+      end
+    }.new
+
+    ActiveRecord::Migrator.new(:up, [migration], @schema_migration).migrate
+
+    assert connection.index_exists?(:testings, [:widget_type, :widget_id], name: :index_testings_on_widget_type_and_widget_id)
+    assert connection.index_exists?(:testings, [:gizmo_type, :gizmo_id], name: :index_testings_on_gizmo_type_and_gizmo_id)
+  end
+
+  def test_create_join_table_with_polymorphic_reference_uses_all_column_names_in_index
+    migration = Class.new(migration_class) {
+      def migrate(x)
+        create_join_table :more, :testings do |t|
+          t.references :widget, polymorphic: true, index: true
+          t.belongs_to :gizmo, polymorphic: true, index: true
+        end
+      end
+    }.new
+
+    ActiveRecord::Migrator.new(:up, [migration], @schema_migration).migrate
+
+    assert connection.index_exists?(:more_testings, [:widget_type, :widget_id], name: :index_more_testings_on_widget_type_and_widget_id)
+    assert connection.index_exists?(:more_testings, [:gizmo_type, :gizmo_id], name: :index_more_testings_on_gizmo_type_and_gizmo_id)
+  ensure
+    connection.drop_table :more_testings rescue nil
+  end
+
+  def test_polymorphic_add_reference_uses_all_column_names_in_index
+    migration = Class.new(migration_class) {
+      def migrate(x)
+        add_reference :testings, :widget, polymorphic: true, index: true
+        add_belongs_to :testings, :gizmo, polymorphic: true, index: true
+      end
+    }.new
+
+    ActiveRecord::Migrator.new(:up, [migration], @schema_migration).migrate
+
+    assert connection.index_exists?(:testings, [:widget_type, :widget_id], name: :index_testings_on_widget_type_and_widget_id)
+    assert connection.index_exists?(:testings, [:gizmo_type, :gizmo_id], name: :index_testings_on_gizmo_type_and_gizmo_id)
+  end
+end
+
+module LegacyPolymorphicReferenceIndexTest
+  class V6_0 < ActiveRecord::TestCase
+    include LegacyPolymorphicReferenceIndexTestCases
+
+    self.use_transactional_tests = false
+
+    private
+      def migration_class
+        ActiveRecord::Migration[6.0]
+      end
+  end
+
+  class V5_2 < V6_0
+    private
+      def migration_class
+        ActiveRecord::Migration[5.2]
+      end
+  end
+
+  class V5_1 < V6_0
+    private
+      def migration_class
+        ActiveRecord::Migration[5.1]
+      end
+  end
+
+  class V5_0 < V6_0
+    private
+      def migration_class
+        ActiveRecord::Migration[5.0]
+      end
+  end
+
+  class V4_2 < V6_0
+    private
+      def migration_class
+        ActiveRecord::Migration[4.2]
+      end
+  end
+end
+
 module LegacyPrimaryKeyTestCases
   include SchemaDumpingHelper
 
