@@ -3,6 +3,7 @@
 require "cases/helper"
 require "models/post"
 require "models/comment"
+require "active_support/core_ext/symbol/starts_ends_with"
 
 module ActiveRecord
   module DelegationTests
@@ -47,10 +48,10 @@ module ActiveRecord
     QUERYING_METHODS =
       ActiveRecord::Batches.public_instance_methods(false) +
       ActiveRecord::Calculations.public_instance_methods(false) +
-      ActiveRecord::FinderMethods.public_instance_methods(false) - [:raise_record_not_found_exception!] +
+      ActiveRecord::FinderMethods.public_instance_methods(false) - [:include?, :member?, :raise_record_not_found_exception!] +
       ActiveRecord::SpawnMethods.public_instance_methods(false) - [:spawn, :merge!] +
       ActiveRecord::QueryMethods.public_instance_methods(false).reject { |method|
-        method.to_s.end_with?("=", "!", "value", "values", "clause")
+        method.end_with?("=", "!", "value", "values", "clause")
       } - [:reverse_order, :arel, :extensions, :construct_join_dependency] + [
         :any?, :many?, :none?, :one?,
         :first_or_create, :first_or_create!, :first_or_initialize,
