@@ -12,6 +12,28 @@ module ActiveRecord
       ])
     end
 
+    test "map! is deprecated" do
+      assert_deprecated do
+        result.map! { nil }
+      end
+      assert_equal [
+        { "col_1" => "row 1 col 1", "col_2" => "row 1 col 2" },
+        { "col_1" => "row 2 col 1", "col_2" => "row 2 col 2" },
+        { "col_1" => "row 3 col 1", "col_2" => "row 3 col 2" },
+      ], result.to_a
+    end
+
+    test "collect! is deprecated" do
+      assert_deprecated do
+        result.collect! { nil }
+      end
+      assert_equal [
+        { "col_1" => "row 1 col 1", "col_2" => "row 1 col 2" },
+        { "col_1" => "row 2 col 1", "col_2" => "row 2 col 2" },
+        { "col_1" => "row 3 col 1", "col_2" => "row 3 col 2" },
+      ], result.to_a
+    end
+
     test "includes_column?" do
       assert result.includes_column?("col_1")
       assert_not result.includes_column?("foo")
@@ -29,24 +51,38 @@ module ActiveRecord
       ], result.to_a
     end
 
-    test "to_hash (deprecated) returns row_hashes" do
-      assert_deprecated do
-        assert_equal [
-          { "col_1" => "row 1 col 1", "col_2" => "row 1 col 2" },
-          { "col_1" => "row 2 col 1", "col_2" => "row 2 col 2" },
-          { "col_1" => "row 3 col 1", "col_2" => "row 3 col 2" },
-        ], result.to_hash
-      end
-    end
-
     test "first returns first row as a hash" do
       assert_equal(
         { "col_1" => "row 1 col 1", "col_2" => "row 1 col 2" }, result.first)
+      assert_equal [
+        { "col_1" => "row 1 col 1", "col_2" => "row 1 col 2" },
+      ], result.first(1)
+      assert_equal [
+        { "col_1" => "row 1 col 1", "col_2" => "row 1 col 2" },
+        { "col_1" => "row 2 col 1", "col_2" => "row 2 col 2" },
+      ], result.first(2)
+      assert_equal [
+        { "col_1" => "row 1 col 1", "col_2" => "row 1 col 2" },
+        { "col_1" => "row 2 col 1", "col_2" => "row 2 col 2" },
+        { "col_1" => "row 3 col 1", "col_2" => "row 3 col 2" },
+      ], result.first(3)
     end
 
     test "last returns last row as a hash" do
       assert_equal(
         { "col_1" => "row 3 col 1", "col_2" => "row 3 col 2" }, result.last)
+      assert_equal [
+        { "col_1" => "row 3 col 1", "col_2" => "row 3 col 2" },
+      ], result.last(1)
+      assert_equal [
+        { "col_1" => "row 2 col 1", "col_2" => "row 2 col 2" },
+        { "col_1" => "row 3 col 1", "col_2" => "row 3 col 2" },
+      ], result.last(2)
+      assert_equal [
+        { "col_1" => "row 1 col 1", "col_2" => "row 1 col 2" },
+        { "col_1" => "row 2 col 1", "col_2" => "row 2 col 2" },
+        { "col_1" => "row 3 col 1", "col_2" => "row 3 col 2" },
+      ], result.last(3)
     end
 
     test "each with block returns row hashes" do
