@@ -6,7 +6,6 @@ require "models/comment"
 require "models/developer"
 require "models/project"
 require "models/computer"
-require "models/vehicle"
 require "models/cat"
 require "concurrent/atomic/cyclic_barrier"
 
@@ -167,10 +166,10 @@ class DefaultScopingTest < ActiveRecord::TestCase
   end
 
   def test_unscope_string_where_clauses_involved
-    dev_relation = Developer.order("salary DESC").where("created_at > ?", 1.year.ago)
+    dev_relation = Developer.order("salary DESC").where("legacy_created_at > ?", 1.year.ago)
     expected = dev_relation.collect(&:name)
 
-    dev_ordered_relation = DeveloperOrderedBySalary.where(name: "Jamis").where("created_at > ?", 1.year.ago)
+    dev_ordered_relation = DeveloperOrderedBySalary.where(name: "Jamis").where("legacy_created_at > ?", 1.year.ago)
     received = dev_ordered_relation.unscope(where: [:name]).collect(&:name)
 
     assert_equal expected.sort, received.sort
@@ -194,7 +193,7 @@ class DefaultScopingTest < ActiveRecord::TestCase
 
   def test_order_to_unscope_reordering
     scope = DeveloperOrderedBySalary.order("salary DESC, name ASC").reverse_order.unscope(:order)
-    assert !/order/i.match?(scope.to_sql)
+    assert_no_match(/order/i, scope.to_sql)
   end
 
   def test_unscope_reverse_order
@@ -408,18 +407,18 @@ class DefaultScopingTest < ActiveRecord::TestCase
   end
 
   def test_joins_not_affected_by_scope_other_than_default_or_unscoped
-    without_scope_on_post = Comment.joins(:post).to_a
+    without_scope_on_post = Comment.joins(:post).sort_by(&:id)
     with_scope_on_post = nil
     Post.where(id: [1, 5, 6]).scoping do
-      with_scope_on_post = Comment.joins(:post).to_a
+      with_scope_on_post = Comment.joins(:post).sort_by(&:id)
     end
 
-    assert_equal with_scope_on_post, without_scope_on_post
+    assert_equal without_scope_on_post, with_scope_on_post
   end
 
   def test_unscoped_with_joins_should_not_have_default_scope
-    assert_equal SpecialPostWithDefaultScope.unscoped { Comment.joins(:special_post_with_default_scope).to_a },
-                 Comment.joins(:post).to_a
+    assert_equal Comment.joins(:post).sort_by(&:id),
+      SpecialPostWithDefaultScope.unscoped { Comment.joins(:special_post_with_default_scope).sort_by(&:id) }
   end
 
   def test_sti_association_with_unscoped_not_affected_by_default_scope
@@ -445,7 +444,7 @@ class DefaultScopingTest < ActiveRecord::TestCase
   end
 
   def test_default_scope_select_ignored_by_grouped_aggregations
-    assert_equal Hash[Developer.all.group_by(&:salary).map { |s, d| [s, d.count] }],
+    assert_equal Developer.all.group_by(&:salary).transform_values(&:count),
                  DeveloperWithSelect.group(:salary).count
   end
 
@@ -499,13 +498,13 @@ class DefaultScopingTest < ActiveRecord::TestCase
 
   test "a scope can remove the condition from the default scope" do
     scope = DeveloperCalledJamis.david2
-    assert_equal 1, scope.where_clause.ast.children.length
+    assert_instance_of Arel::Nodes::Equality, scope.where_clause.ast
     assert_equal Developer.where(name: "David").map(&:id), scope.map(&:id)
   end
 
   def test_with_abstract_class_where_clause_should_not_be_duplicated
-    scope = Bus.all
-    assert_equal scope.where_clause.ast.children.length, 1
+    scope = Lion.all
+    assert_instance_of Arel::Nodes::Equality, scope.where_clause.ast
   end
 
   def test_sti_conditions_are_not_carried_in_default_scope
@@ -523,13 +522,8 @@ class DefaultScopingTest < ActiveRecord::TestCase
   end
 
   def test_with_abstract_class_scope_should_be_executed_in_correct_context
-    vegetarian_pattern, gender_pattern = if current_adapter?(:Mysql2Adapter)
-      [/`lions`.`is_vegetarian`/, /`lions`.`gender`/]
-    elsif current_adapter?(:OracleAdapter)
-      [/"LIONS"."IS_VEGETARIAN"/, /"LIONS"."GENDER"/]
-    else
-      [/"lions"."is_vegetarian"/, /"lions"."gender"/]
-    end
+    vegetarian_pattern = /#{Regexp.escape(Lion.connection.quote_table_name("lions.is_vegetarian"))}/i
+    gender_pattern     = /#{Regexp.escape(Lion.connection.quote_table_name("lions.gender"))}/i
 
     assert_match vegetarian_pattern, Lion.all.to_sql
     assert_match gender_pattern, Lion.female.to_sql
