@@ -23,3 +23,11 @@ end
 class RedCabbage < Cabbage
   belongs_to :seller, class_name: "Company"
 end
+
+class YellingVegetable < Vegetable
+  after_initialize :format_name
+
+  def format_name
+    self.name = name&.upcase
+  end
+end
