@@ -11,7 +11,7 @@ module ARTest
     ENV["ARCONN"] || config["default_connection"]
   end
 
-  def self.connection_config
+  def self.test_configuration_hashes
     config.fetch("connections").fetch(connection_name) do
       puts "Connection #{connection_name.inspect} not found. Available connections: #{config['connections'].keys.join(', ')}"
       exit 1
@@ -19,10 +19,10 @@ module ARTest
   end
 
   def self.connect
+    ActiveRecord::Base.legacy_connection_handling = false
     puts "Using #{connection_name}"
     ActiveRecord::Base.logger = ActiveSupport::Logger.new("debug.log", 0, 100 * 1024 * 1024)
-    ActiveRecord::Base.connection_handlers = { ActiveRecord::Base.writing_role => ActiveRecord::Base.default_connection_handler }
-    ActiveRecord::Base.configurations = connection_config
+    ActiveRecord::Base.configurations = test_configuration_hashes
     ActiveRecord::Base.establish_connection :arunit
     ARUnit2Model.establish_connection :arunit2
   end
