@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require "abstract_unit"
+require_relative "abstract_unit"
 
 module ActiveSupport
   class BroadcastLoggerTest < TestCase
@@ -18,7 +18,7 @@ module ActiveSupport
       level = Logger::Severity.const_get(level_name)
 
       test "##{method} adds the message to all loggers" do
-        logger.send(method, "msg")
+        logger.public_send(method, "msg")
 
         assert_equal [level, "msg", nil], log1.adds.first
         assert_equal [level, "msg", nil], log2.adds.first
@@ -114,14 +114,6 @@ module ActiveSupport
       assert_equal [[::Logger::FATAL, "seen", nil]], log2.adds
     end
 
-    test "Including top constant LoggerSilence is deprecated" do
-      assert_deprecated("Please use `ActiveSupport::LoggerSilence`") do
-        Class.new(CustomLogger) do
-          include ::LoggerSilence
-        end
-      end
-    end
-
     class CustomLogger
       include ActiveSupport::LoggerSilence
 
