@@ -20,7 +20,7 @@ class CleanLoggerTest < ActiveSupport::TestCase
     @logger.formatter.datetime_format = "%Y-%m-%d"
     @logger.debug "debug"
     assert_equal "%Y-%m-%d", @logger.formatter.datetime_format
-    assert_match(/D, \[\d\d\d\d-\d\d-\d\d#\d+\] DEBUG -- : debug/, @out.string)
+    assert_match(/D, \[\d\d\d\d-\d\d-\d\d[ ]?#\d+\] DEBUG -- : debug/, @out.string)
   end
 
   def test_nonstring_formatting
