@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require "abstract_unit"
+require_relative "../../abstract_unit"
 require "bigdecimal"
 require "active_support/core_ext/object/duplicable"
 require "active_support/core_ext/numeric/time"
