@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
-require "abstract_unit"
-require "active_support/core_ext/object"
+require_relative "../../abstract_unit"
+require "active_support/core_ext/object/instance_variables"
 
 class ObjectInstanceVariableTest < ActiveSupport::TestCase
   def setup
