@@ -1,15 +1,19 @@
 # frozen_string_literal: true
 
-require "abstract_unit"
+require_relative "abstract_unit"
+require "active_support/current_attributes/test_helper"
 
 class CurrentAttributesTest < ActiveSupport::TestCase
+  # Automatically included in Rails apps via railtie but that dodn't run here.
+  include ActiveSupport::CurrentAttributes::TestHelper
+
   Person = Struct.new(:id, :name, :time_zone)
 
   class Current < ActiveSupport::CurrentAttributes
     attribute :world, :account, :person, :request
     delegate :time_zone, to: :person
 
-    before_reset { Session.previous = person.try(:id) }
+    before_reset { Session.previous = person&.id }
 
     resets do
       Time.zone = "UTC"
@@ -18,13 +22,24 @@ class CurrentAttributesTest < ActiveSupport::TestCase
 
     def account=(account)
       super
-      self.person = "#{account}'s person"
+      self.person = Person.new(1, "#{account}'s person")
     end
 
     def person=(person)
       super
-      Time.zone = person.try(:time_zone)
-      Session.current = person.try(:id)
+      Time.zone = person&.time_zone
+      Session.current = person&.id
+    end
+
+    def set_world_and_account(world:, account:)
+      self.world = world
+      self.account = account
+    end
+
+    def get_world_and_account(hash)
+      hash[:world] = world
+      hash[:account] = account
+      hash
     end
 
     def request
@@ -40,16 +55,23 @@ class CurrentAttributesTest < ActiveSupport::TestCase
     attribute :current, :previous
   end
 
-  setup do
+  # Eagerly set-up `instance`s by reference.
+  [ Current.instance, Session.instance ]
+
+  # Use library specific minitest hook to catch Time.zone before reset is called via TestHelper
+  def before_setup
     @original_time_zone = Time.zone
-    Current.reset
-    Session.reset
+    super
   end
 
-  teardown do
+  # Use library specific minitest hook to set Time.zone after reset is called via TestHelper
+  def after_teardown
+    super
     Time.zone = @original_time_zone
   end
 
+  setup { assert_nil Session.previous, "Expected Session to not have leaked state" }
+
   test "read and write attribute" do
     Current.world = "world/1"
     assert_equal "world/1", Current.world
@@ -63,7 +85,7 @@ class CurrentAttributesTest < ActiveSupport::TestCase
   test "set attribute via overwritten method" do
     Current.account = "account/1"
     assert_equal "account/1", Current.account
-    assert_equal "account/1's person", Current.person
+    assert_equal "account/1's person", Current.person.name
   end
 
   test "set auxiliary class via overwritten method" do
@@ -78,6 +100,7 @@ class CurrentAttributesTest < ActiveSupport::TestCase
 
     Current.reset
     assert_equal "UTC", Time.zone.name
+    assert_equal 42, Session.previous
     assert_nil Session.current
   end
 
@@ -114,6 +137,26 @@ class CurrentAttributesTest < ActiveSupport::TestCase
     assert_equal "account/1", Current.account
   end
 
+  test "using keyword arguments" do
+    Current.set_world_and_account(world: "world/1", account: "account/1")
+
+    assert_equal "world/1", Current.world
+    assert_equal "account/1", Current.account
+
+    hash = {}
+    assert_same hash, Current.get_world_and_account(hash)
+    assert_equal "world/1", hash[:world]
+    assert_equal "account/1", hash[:account]
+  end
+
+  setup { @testing_teardown = false }
+  teardown { assert_equal 42, Session.current if @testing_teardown }
+
+  test "accessing attributes in teardown" do
+    Session.current = 42
+    @testing_teardown = true
+  end
+
   test "delegation" do
     Current.person = Person.new(42, "David", "Central Time (US & Canada)")
     assert_equal "Central Time (US & Canada)", Current.time_zone
