@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require "abstract_unit"
+require_relative "abstract_unit"
 require "active_support/number_helper"
 require "active_support/core_ext/string/output_safety"
 
@@ -71,6 +71,7 @@ module ActiveSupport
           assert_equal("-$ 1,234,567,890.50", number_helper.number_to_currency(-1234567890.50, format: "%u %n"))
           assert_equal("($1,234,567,890.50)", number_helper.number_to_currency(-1234567890.50, negative_format: "(%u%n)"))
           assert_equal("$1,234,567,892", number_helper.number_to_currency(1234567891.50, precision: 0))
+          assert_equal("$1,234,567,891", number_helper.number_to_currency(1234567891.50, precision: 0, round_mode: :down))
           assert_equal("$1,234,567,890.5", number_helper.number_to_currency(1234567890.50, precision: 1))
           assert_equal("&pound;1234567890,50", number_helper.number_to_currency(1234567890.50, unit: "&pound;", separator: ",", delimiter: ""))
           assert_equal("$1,234,567,890.50", number_helper.number_to_currency("1234567890.50"))
@@ -78,6 +79,12 @@ module ActiveSupport
           assert_equal("1,234,567,890.50 - K&#269;", number_helper.number_to_currency("-1234567890.50", unit: "K&#269;", format: "%n %u", negative_format: "%n - %u"))
           assert_equal("0.00", number_helper.number_to_currency(+0.0, unit: "", negative_format: "(%n)"))
           assert_equal("$0", number_helper.number_to_currency(-0.456789, precision: 0))
+          assert_equal("$1,11", number_helper.number_to_currency("1,11"))
+          assert_equal("$0,11", number_helper.number_to_currency("0,11"))
+          assert_equal("$,11", number_helper.number_to_currency(",11"))
+          assert_equal("-$1,11", number_helper.number_to_currency("-1,11"))
+          assert_equal("-$0,11", number_helper.number_to_currency("-0,11"))
+          assert_equal("-$,11", number_helper.number_to_currency("-,11"))
         end
       end
 
@@ -86,6 +93,7 @@ module ActiveSupport
           assert_equal("100.000%", number_helper.number_to_percentage(100))
           assert_equal("100%", number_helper.number_to_percentage(100, precision: 0))
           assert_equal("302.06%", number_helper.number_to_percentage(302.0574, precision: 2))
+          assert_equal("302.05%", number_helper.number_to_percentage(302.0574, precision: 2, round_mode: :down))
           assert_equal("100.000%", number_helper.number_to_percentage("100"))
           assert_equal("1000.000%", number_helper.number_to_percentage("1000"))
           assert_equal("123.4%", number_helper.number_to_percentage(123.400, precision: 3, strip_insignificant_zeros: true))
@@ -136,6 +144,7 @@ module ActiveSupport
           assert_equal("111.235", number_helper.number_to_rounded(111.2346))
           assert_equal("31.83", number_helper.number_to_rounded(31.825, precision: 2))
           assert_equal("111.23", number_helper.number_to_rounded(111.2346, precision: 2))
+          assert_equal("111.24", number_helper.number_to_rounded(111.2346, precision: 2, round_mode: :up))
           assert_equal("111.00", number_helper.number_to_rounded(111, precision: 2))
           assert_equal("111.235", number_helper.number_to_rounded("111.2346"))
           assert_equal("31.83", number_helper.number_to_rounded("31.825", precision: 2))
@@ -188,6 +197,7 @@ module ActiveSupport
           assert_equal "10.0", number_helper.number_to_rounded(9.995, precision: 3, significant: true)
           assert_equal "9.99", number_helper.number_to_rounded(9.994, precision: 3, significant: true)
           assert_equal "11.0", number_helper.number_to_rounded(10.995, precision: 3, significant: true)
+          assert_equal "123000", number_helper.number_to_rounded(123987, precision: 3, significant: true, round_mode: :down)
 
           assert_equal "9775.0000000000000000", number_helper.number_to_rounded(9775, precision: 20, significant: true)
           assert_equal "9775.0000000000000000", number_helper.number_to_rounded(9775.0, precision: 20, significant: true)
@@ -197,6 +207,8 @@ module ActiveSupport
           assert_equal "9775.0000000000000000", number_helper.number_to_rounded("9775", precision: 20, significant: true)
           assert_equal "9775." + "0" * 96, number_helper.number_to_rounded("9775", precision: 100, significant: true)
           assert_equal("97.7", number_helper.number_to_rounded(Rational(9772, 100), precision: 3, significant: true))
+          assert_equal "28729870200000000000000", number_helper.number_to_rounded(0.287298702e23.to_d, precision: 0, significant: true)
+          assert_equal "-Inf", number_helper.number_to_rounded(-Float::INFINITY, precision: 0, significant: true)
         end
       end
 
@@ -237,6 +249,7 @@ module ActiveSupport
           assert_equal "1020 MB",   number_helper.number_to_human_size(megabytes(1023))
           assert_equal "3 TB",      number_helper.number_to_human_size(terabytes(3))
           assert_equal "1.2 MB",   number_helper.number_to_human_size(1234567, precision: 2)
+          assert_equal "1.1 MB",   number_helper.number_to_human_size(1234567, precision: 2, round_mode: :down)
           assert_equal "3 Bytes",   number_helper.number_to_human_size(3.14159265, precision: 4)
           assert_equal "123 Bytes", number_helper.number_to_human_size("123")
           assert_equal "1 KB",   number_helper.number_to_human_size(kilobytes(1.0123), precision: 2)
@@ -259,6 +272,7 @@ module ActiveSupport
           assert_equal "10 MB", number_helper.number_to_human_size(9961472, precision: 0)
           assert_equal "40 KB", number_helper.number_to_human_size(41010, precision: 1)
           assert_equal "40 KB", number_helper.number_to_human_size(41100, precision: 2)
+          assert_equal "50 KB", number_helper.number_to_human_size(41100, precision: 1, round_mode: :up)
           assert_equal "1.0 KB",   number_helper.number_to_human_size(kilobytes(1.0123), precision: 2, strip_insignificant_zeros: false)
           assert_equal "1.012 KB",   number_helper.number_to_human_size(kilobytes(1.0123), precision: 3, significant: false)
           assert_equal "1 KB",   number_helper.number_to_human_size(kilobytes(1.0123), precision: 0, significant: true) # ignores significant it precision is 0
@@ -290,6 +304,7 @@ module ActiveSupport
           assert_equal "490 Thousand", number_helper.number_to_human(489939, precision: 2)
           assert_equal "489.9 Thousand", number_helper.number_to_human(489939, precision: 4)
           assert_equal "489 Thousand", number_helper.number_to_human(489000, precision: 4)
+          assert_equal "480 Thousand", number_helper.number_to_human(489939, precision: 2, round_mode: :down)
           assert_equal "489.0 Thousand", number_helper.number_to_human(489000, precision: 4, strip_insignificant_zeros: false)
           assert_equal "1.2346 Million", number_helper.number_to_human(1234567, precision: 4, significant: false)
           assert_equal "1,2 Million", number_helper.number_to_human(1234567, precision: 1, significant: false, separator: ",")
