@@ -1,8 +1,6 @@
 (function() {
   "use strict";
 
-  this.syntaxhighlighterConfig = { autoLinks: false };
-
   this.wrap = function(elem, wrapper) {
     elem.parentNode.insertBefore(wrapper, elem);
     wrapper.appendChild(elem);
@@ -29,8 +27,6 @@
   if (window.location.protocol === "file:") Turbolinks.supported = false;
 
   document.addEventListener("turbolinks:load", function() {
-    window.SyntaxHighlighter.highlight({ "auto-links": false });
-
     var guidesMenu = document.getElementById("guidesMenu");
     var guides     = document.getElementById("guides");
 
@@ -71,5 +67,16 @@
         unwrap(moreInfoLinks);
       }
     });
+
+    var clipboard = new ClipboardJS('.clipboard-button');
+    clipboard.on('success', function(e) {
+      var trigger = e.trigger;
+      var triggerLabel = trigger.innerHTML;
+      trigger.innerHTML = 'Copied!';
+      setTimeout(function(){
+        trigger.innerHTML = triggerLabel;
+      }, 3000);
+      e.clearSelection();
+    });
   });
 }).call(this);
