@@ -2260,6 +2260,23 @@ module ApplicationTests
       assert_equal([Symbol], ActiveRecord::Base.yaml_column_permitted_classes)
     end
 
+    test "config.active_record.raise_int_wider_than_64bit is true by default" do
+      app "production"
+      assert ActiveRecord::Base.raise_int_wider_than_64bit
+    end
+
+    test "config.active_record.raise_int_wider_than_64bit can be configured" do
+      remove_from_config '.*config\.load_defaults.*\n'
+
+      app_file "config/initializers/dont_raise.rb", <<-RUBY
+        Rails.application.config.active_record.raise_int_wider_than_64bit = false
+      RUBY
+
+      app "production"
+      assert_not ActiveRecord::Base.raise_int_wider_than_64bit
+    end
+
+
     test "ActiveRecord::Base.has_many_inversing is true by default for new apps" do
       app "development"
 
