@@ -31,7 +31,7 @@ module ApplicationTests
       add_to_config "config.force_ssl = true"
       add_to_config "config.ssl_options = { secure_cookies: false }"
       require "#{app_path}/config/environment"
-      assert !app.config.session_options[:secure]
+      assert_not app.config.session_options[:secure]
     end
 
     test "session is not loaded if it's not used" do
@@ -51,7 +51,7 @@ module ApplicationTests
       get "/"
 
       assert last_request.env["HTTP_COOKIE"]
-      assert !last_response.headers["Set-Cookie"]
+      assert_not last_response.headers["Set-Cookie"]
     end
 
     test "session is empty and isn't saved on unverified request when using :null_session protect method" do
@@ -183,7 +183,7 @@ module ApplicationTests
       encryptor = ActiveSupport::MessageEncryptor.new(secret[0, ActiveSupport::MessageEncryptor.key_len(cipher)], cipher: cipher)
 
       get "/foo/read_raw_cookie"
-      assert_equal 1, encryptor.decrypt_and_verify(last_response.body)["foo"]
+      assert_equal 1, encryptor.decrypt_and_verify(last_response.body, purpose: "cookie._myapp_session")["foo"]
     end
 
     test "session upgrading signature to encryption cookie store works the same way as encrypted cookie store" do
@@ -215,8 +215,6 @@ module ApplicationTests
       RUBY
 
       add_to_config <<-RUBY
-        secrets.secret_token = "3b7cd727ee24e8444053437c36cc66c4"
-
         # Enable AEAD cookies
         config.action_dispatch.use_authenticated_cookie_encryption = true
       RUBY
@@ -235,69 +233,7 @@ module ApplicationTests
       encryptor = ActiveSupport::MessageEncryptor.new(secret[0, ActiveSupport::MessageEncryptor.key_len(cipher)], cipher: cipher)
 
       get "/foo/read_raw_cookie"
-      assert_equal 1, encryptor.decrypt_and_verify(last_response.body)["foo"]
-    end
-
-    test "session upgrading signature to encryption cookie store upgrades session to encrypted mode" do
-      app_file "config/routes.rb", <<-RUBY
-        Rails.application.routes.draw do
-          get ':controller(/:action)'
-        end
-      RUBY
-
-      controller :foo, <<-RUBY
-        class FooController < ActionController::Base
-          def write_raw_session
-            # {"session_id"=>"1965d95720fffc123941bdfb7d2e6870", "foo"=>1}
-            cookies[:_myapp_session] = "BAh7B0kiD3Nlc3Npb25faWQGOgZFRkkiJTE5NjVkOTU3MjBmZmZjMTIzOTQxYmRmYjdkMmU2ODcwBjsAVEkiCGZvbwY7AEZpBg==--315fb9931921a87ae7421aec96382f0294119749"
-            head :ok
-          end
-
-          def write_session
-            session[:foo] = session[:foo] + 1
-            head :ok
-          end
-
-          def read_session
-            render plain: session[:foo]
-          end
-
-          def read_encrypted_cookie
-            render plain: cookies.encrypted[:_myapp_session]['foo']
-          end
-
-          def read_raw_cookie
-            render plain: cookies[:_myapp_session]
-          end
-        end
-      RUBY
-
-      add_to_config <<-RUBY
-        secrets.secret_token = "3b7cd727ee24e8444053437c36cc66c4"
-
-        # Enable AEAD cookies
-        config.action_dispatch.use_authenticated_cookie_encryption = true
-      RUBY
-
-      require "#{app_path}/config/environment"
-
-      get "/foo/write_raw_session"
-      get "/foo/read_session"
-      assert_equal "1", last_response.body
-
-      get "/foo/write_session"
-      get "/foo/read_session"
-      assert_equal "2", last_response.body
-
-      get "/foo/read_encrypted_cookie"
-      assert_equal "2", last_response.body
-
-      cipher = "aes-256-gcm"
-      secret = app.key_generator.generate_key("authenticated encrypted cookie")
-      encryptor = ActiveSupport::MessageEncryptor.new(secret[0, ActiveSupport::MessageEncryptor.key_len(cipher)], cipher: cipher)
-
-      get "/foo/read_raw_cookie"
-      assert_equal 2, encryptor.decrypt_and_verify(last_response.body)["foo"]
+      assert_equal 1, encryptor.decrypt_and_verify(last_response.body, purpose: "cookie._myapp_session")["foo"]
     end
 
     test "session upgrading from AES-CBC-HMAC encryption to AES-GCM encryption" do
@@ -364,71 +300,7 @@ module ApplicationTests
         encryptor = ActiveSupport::MessageEncryptor.new(secret[0, ActiveSupport::MessageEncryptor.key_len(cipher)], cipher: cipher)
 
         get "/foo/read_raw_cookie"
-        assert_equal 2, encryptor.decrypt_and_verify(last_response.body)["foo"]
-      ensure
-        ENV["RAILS_ENV"] = old_rails_env
-      end
-    end
-
-    test "session upgrading legacy signed cookies to new signed cookies" do
-      app_file "config/routes.rb", <<-RUBY
-        Rails.application.routes.draw do
-          get ':controller(/:action)'
-        end
-      RUBY
-
-      controller :foo, <<-RUBY
-        class FooController < ActionController::Base
-          def write_raw_session
-            # {"session_id"=>"1965d95720fffc123941bdfb7d2e6870", "foo"=>1}
-            cookies[:_myapp_session] = "BAh7B0kiD3Nlc3Npb25faWQGOgZFRkkiJTE5NjVkOTU3MjBmZmZjMTIzOTQxYmRmYjdkMmU2ODcwBjsAVEkiCGZvbwY7AEZpBg==--315fb9931921a87ae7421aec96382f0294119749"
-            head :ok
-          end
-
-          def write_session
-            session[:foo] = session[:foo] + 1
-            head :ok
-          end
-
-          def read_session
-            render plain: session[:foo]
-          end
-
-          def read_signed_cookie
-            render plain: cookies.signed[:_myapp_session]['foo']
-          end
-
-          def read_raw_cookie
-            render plain: cookies[:_myapp_session]
-          end
-        end
-      RUBY
-
-      add_to_config <<-RUBY
-        secrets.secret_token = "3b7cd727ee24e8444053437c36cc66c4"
-        Rails.application.credentials.secret_key_base = nil
-      RUBY
-
-      begin
-        old_rails_env, ENV["RAILS_ENV"] = ENV["RAILS_ENV"], "production"
-
-        require "#{app_path}/config/environment"
-
-        get "/foo/write_raw_session"
-        get "/foo/read_session"
-        assert_equal "1", last_response.body
-
-        get "/foo/write_session"
-        get "/foo/read_session"
-        assert_equal "2", last_response.body
-
-        get "/foo/read_signed_cookie"
-        assert_equal "2", last_response.body
-
-        verifier = ActiveSupport::MessageVerifier.new(app.secrets.secret_token)
-
-        get "/foo/read_raw_cookie"
-        assert_equal 2, verifier.verify(last_response.body)["foo"]
+        assert_equal 2, encryptor.decrypt_and_verify(last_response.body, purpose: "cookie._myapp_session")["foo"]
       ensure
         ENV["RAILS_ENV"] = old_rails_env
       end
