@@ -476,7 +476,7 @@ module ApplicationTests
 
           add_to_config("config.active_support.deprecation = :stderr")
           stderr_output = capture(:stderr) { rails("db:structure:#{command}:animals", stderr: true, allow_failure: true) }
-          assert_match(/DEPRECATION WARNING: Using `bin\/rails db:structure:#{command}:animals` is deprecated and will be removed in Rails 6.2/, stderr_output)
+          assert_match(/DEPRECATION WARNING: Using `bin\/rails db:structure:#{command}:animals` is deprecated and will be removed in Rails 7.0/, stderr_output)
         end
       end
 
@@ -611,6 +611,20 @@ module ApplicationTests
         db_migrate_and_schema_cache_dump
       end
 
+      test "db:prepare setup the database even if schema does not exist" do
+        Dir.chdir(app_path) do
+          use_postgresql(multi_db: true) # bug doesn't exist with sqlite3
+          output = rails("db:drop")
+          assert_match(/Dropped database/, output)
+
+          rails "generate", "model", "recipe", "title:string"
+          output = rails("db:prepare")
+          assert_match(/CreateRecipes: migrated/, output)
+        end
+      ensure
+        rails "db:drop" rescue nil
+      end
+
       # Note that schema cache loader depends on the connection and
       # does not work for all connections.
       test "schema_cache is loaded on primary db in multi-db app" do
@@ -813,7 +827,7 @@ module ApplicationTests
         db_create_and_drop_namespace("primary", "db/development.sqlite3")
       end
 
-      test "a thing" do
+      test "when there is no primary config, the first is chosen as the default" do
         app_file "config/database.yml", <<-YAML
           development:
             default:
