@@ -265,6 +265,30 @@ module ApplicationTests
       assert_equal "WIN", last_response.body
     end
 
+    test "routes drawing from config/routes" do
+      app_file "config/routes.rb", <<-RUBY
+        AppTemplate::Application.routes.draw do
+          draw :external
+        end
+      RUBY
+
+      app_file "config/routes/external.rb", <<-RUBY
+        get ':controller/:action'
+      RUBY
+
+      controller :success, <<-RUBY
+        class SuccessController < ActionController::Base
+          def index
+            render plain: "success!"
+          end
+        end
+      RUBY
+
+      app "development"
+      get "/success/index"
+      assert_equal "success!", last_response.body
+    end
+
     {
       "development" => ["baz", "http://www.apple.com", "/dashboard"],
       "production"  => ["bar", "http://www.microsoft.com", "/profile"]
@@ -307,7 +331,7 @@ module ApplicationTests
 
         app_file "config/routes.rb", <<-RUBY
           Rails.application.routes.draw do
-            get 'foo', to: 'foo#bar'
+            draw :external
             get 'custom', to: 'foo#custom'
             get 'mapping', to: 'foo#mapping'
 
@@ -316,6 +340,10 @@ module ApplicationTests
           end
         RUBY
 
+        app_file "config/routes/external.rb", <<-RUBY
+          get 'foo', to: 'foo#bar'
+        RUBY
+
         app(mode)
 
         get "/foo"
@@ -329,7 +357,7 @@ module ApplicationTests
 
         app_file "config/routes.rb", <<-RUBY
           Rails.application.routes.draw do
-            get 'foo', to: 'foo#baz'
+            draw :another_external
             get 'custom', to: 'foo#custom'
             get 'mapping', to: 'foo#mapping'
 
@@ -338,6 +366,10 @@ module ApplicationTests
           end
         RUBY
 
+        app_file "config/routes/another_external.rb", <<-RUBY
+          get 'foo', to: 'foo#baz'
+        RUBY
+
         sleep 0.1
 
         get "/foo"
