@@ -91,11 +91,12 @@ class ApiAppGeneratorTest < Rails::Generators::TestCase
 
     generator = Rails::Generators::AppGenerator.new ["rails"],
       { api: true, update: true }, { destination_root: destination_root, shell: @shell }
-    quietly { generator.send(:update_config_files) }
+    quietly { generator.update_config_files }
 
     assert_no_file "config/initializers/cookies_serializer.rb"
     assert_no_file "config/initializers/assets.rb"
     assert_no_file "config/initializers/content_security_policy.rb"
+    assert_no_file "config/initializers/permissions_policy.rb"
   end
 
   def test_app_update_does_not_generate_unnecessary_bin_files
@@ -103,7 +104,7 @@ class ApiAppGeneratorTest < Rails::Generators::TestCase
 
     generator = Rails::Generators::AppGenerator.new ["rails"],
       { api: true, update: true }, { destination_root: destination_root, shell: @shell }
-    quietly { generator.send(:update_bin_files) }
+    quietly { generator.update_bin_files }
 
     assert_no_file "bin/yarn"
   end
@@ -171,6 +172,7 @@ class ApiAppGeneratorTest < Rails::Generators::TestCase
          config/initializers/assets.rb
          config/initializers/cookies_serializer.rb
          config/initializers/content_security_policy.rb
+         config/initializers/permissions_policy.rb
          lib/assets
          test/helpers
          tmp/cache/assets
