@@ -9,13 +9,11 @@ class AssetsGeneratorTest < Rails::Generators::TestCase
 
   def test_assets
     run_generator
-    assert_file "app/assets/javascripts/posts.js"
     assert_file "app/assets/stylesheets/posts.css"
   end
 
   def test_skipping_assets
-    run_generator ["posts", "--no-stylesheets", "--no-javascripts"]
-    assert_no_file "app/assets/javascripts/posts.js"
+    run_generator ["posts", "--no-stylesheets"]
     assert_no_file "app/assets/stylesheets/posts.css"
   end
 end
